@@ -23,6 +23,7 @@
 
 #include "lugdulov.h"
 
+#include "tools.h"
 #include "stationsplugin.h"
 #include "stationspluginmanager.h"
 #include "station.h"
@@ -32,28 +33,42 @@
 #include "pluginsdialog.h"
 #include "mapdialog.h"
 #include "settings.h"
+#include "aboutdialog.h"
 
 MainWindow::MainWindow(QWidget *parent)
   : QMainWindow(parent)
 {
   setupUi(this);
 
-  plugin = NULL;
 #ifdef HAVE_QT_LOCATION
   localisation = NULL;
 #endif
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
   menu_File->removeAction(quitAction);
   menu_Help->removeAction(aboutQtAction);
   setAttribute(Qt::WA_Maemo5StackedWindow);
   setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
-  mapLinkButton->setMaximumHeight(70);
-  searchLinkButton->setMaximumHeight(70);
-  bookmarkLinkButton->setMaximumHeight(70);
-
   searchLinkButton->setDescription(tr("Search stations by name"));
   bookmarkLinkButton->setDescription(tr("Manage your favorites stations."));
+#elif defined(Q_WS_S60) || defined(Q_WS_SIMULATOR)
+  pushButton->setIconSize(QSize(24,24));
+  searchLinkButton->setDescription(QString());
+  bookmarkLinkButton->setDescription(QString());
+  mapLinkButton->setDescription(QString());
+#endif
+
+#if defined(Q_WS_S60) || defined(Q_WS_SIMULATOR) || defined(Q_WS_MAEMO_5)
+  iconLabel->hide();
+  titleLabel->hide();
+#endif
+
+#if defined(Q_WS_MAEMO_5)
+  progressBar = NULL;
+#else
+  progressBar = new QProgressBar(this);
+  progressBar->hide();
+  statusBar()->addPermanentWidget(progressBar, 0);
 #endif
 
   plugin = NULL;
@@ -104,18 +119,15 @@ MainWindow::createActions()
 void
 MainWindow::delayedInit()
 {
-#ifdef HAVE_QT_BEARER
-  QNetworkConfigurationManager mgr;
-  QNetworkConfiguration ap = mgr.defaultConfiguration();
-  QNetworkSession* session = new QNetworkSession(ap);
+#if defined(HAVE_QT_BEARER) || QT_VERSION >= 0x040700
+  QNetworkConfigurationManager manager;
+  const bool selectIap = (manager.capabilities()& QNetworkConfigurationManager::CanStartAndStopInterfaces);
+  QNetworkConfiguration ap = manager.defaultConfiguration();
+  QNetworkSession* session = new QNetworkSession(ap, this);
+
+  (void) selectIap;
 
   session->open();
-
-  if (!session->waitForOpened(-1)) {
-    QMessageBox::critical(this, tr("Network Error"), session->errorString());
-    QApplication::instance()->quit();
-    return ;
-  }
 #endif
 #ifdef HAVE_QT_LOCATION
   localisation = QGeoPositionInfoSource::createDefaultSource(this);
@@ -127,7 +139,7 @@ MainWindow::delayedInit()
 
   connect(localisation, SIGNAL(positionUpdated(QGeoPositionInfo)),
 	  this, SLOT(positionUpdated(QGeoPositionInfo)));
-  connect(localisation, SIGNAL(requestTimeout()), this, SLOT(positionRequestTimeout()));
+  connect(localisation, SIGNAL(updateTimeout()), this, SLOT(positionRequestTimeout()));
 
   localisation->setUpdateInterval(5000);
   localisation->startUpdates();
@@ -156,7 +168,7 @@ MainWindow::positionUpdated(QGeoPositionInfo info)
 
   QPointF pt(coord.latitude(), coord.longitude());
 
-  if (plugin && plugin->rect().contains(pt))
+  if (plugin) // && plugin->rect().contains(pt))
     return ;
 
   foreach (StationsPlugin *plugin, manager->stations().values())
@@ -177,10 +189,20 @@ MainWindow::buttonClicked()
 void
 MainWindow::setStationsPlugin(StationsPlugin *sta, bool save)
 {
+  if (plugin)
+    disconnect(plugin, 0, this, 0);
+
   plugin = sta;
+
   if (plugin) {
     pushButton->setText(plugin->name());
     pushButton->setIcon(plugin->bikeIcon());
+
+    connect(plugin, SIGNAL(progress(qint64, qint64)), this, SLOT(progress(qint64, qint64)));
+
+    QTimer::singleShot(1, this, SLOT(updatePlugin()));
+  } else {
+    pushButton->setText(tr("Auto"));
   }
   if (save) {
     Settings conf;
@@ -191,25 +213,9 @@ MainWindow::setStationsPlugin(StationsPlugin *sta, bool save)
 void
 MainWindow::about()
 {
-  QMessageBox::about(this, tr("About Lugdulo'v " LUGDULOV_VERSION),
-		     tr("Version: " LUGDULOV_VERSION "\n"
-			"Home: http://xf.iksaif.net/dev/lugdulov.html\n\n"
-			"Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>\n"
-			"Copyright (C) 2010 Patrick Installé <PatrickInstalle@P-Installe.be>\n"
-			"\n"
-			"This program is free software; you can redistribute it and/or modify\n"
-			"it under the terms of the GNU General Public License as published by\n"
-			"the Free Software Foundation; either version 2 of the License, or\n"
-			"(at your option) any later version.\n"
-			"\n"
-			"This program is distributed in the hope that it will be useful, but\n"
-			"WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n"
-			"or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License\n"
-			"for more details.\n"
-			"\n"
-			"You should have received a copy of the GNU General Public License along\n"
-			"with this program; if not, write to the Free Software Foundation, Inc.,\n"
-			"59 Temple Place, Suite 330, Boston, MA 02111-1307 USA\n"));
+  AboutDialog dialog(this);
+
+  dialog.exec();
 }
 
 void
@@ -243,7 +249,7 @@ MainWindow::search()
 #ifdef HAVE_QT_LOCATION
   if (localisation) {
     connect(localisation, SIGNAL(positionUpdated(QGeoPositionInfo)), dlg, SLOT(positionUpdated(QGeoPositionInfo)));
-    connect(localisation, SIGNAL(requestTimeout()), dlg, SLOT(positionRequestTimeout()));
+    connect(localisation, SIGNAL(updateTimeout()), dlg, SLOT(positionRequestTimeout()));
 
     if (position.isValid())
       dlg->positionUpdated(position);
@@ -266,9 +272,13 @@ MainWindow::map()
 
 #ifdef HAVE_QT_LOCATION
   if (localisation) {
-    connect(localisation, SIGNAL(positionUpdated(QGeoPositionInfo)), map, SLOT(positionUpdated(QGeoPositionInfo)));
+    QGeoCoordinate coord = position.coordinate();
+    QPointF pt(coord.latitude(), coord.longitude());
 
-    if (position.isValid()) {
+    connect(localisation, SIGNAL(positionUpdated(QGeoPositionInfo)),
+	    map, SLOT(positionUpdated(QGeoPositionInfo)));
+
+    if (coord.isValid() && plugin->rect().contains(pt)) {
       zoom = 0;
       map->positionUpdated(position);
     }
@@ -292,8 +302,9 @@ MainWindow::bookmarks()
 
 #ifdef HAVE_QT_LOCATION
   if (localisation) {
-    connect(localisation, SIGNAL(positionUpdated(QGeoPositionInfo)), dlg, SLOT(positionUpdated(QGeoPositionInfo)));
-    connect(localisation, SIGNAL(requestTimeout()), dlg, SLOT(positionRequestTimeout()));
+    connect(localisation, SIGNAL(positionUpdated(QGeoPositionInfo)),
+	    dlg, SLOT(positionUpdated(QGeoPositionInfo)));
+    connect(localisation, SIGNAL(updateTimeout()), dlg, SLOT(positionRequestTimeout()));
 
     if (position.isValid())
       dlg->positionUpdated(position);
@@ -311,3 +322,48 @@ MainWindow::chooseStationsPlugin()
 
   buttonClicked();
 }
+
+void
+MainWindow::progress(qint64 done, qint64 total)
+{
+  if (!progressBar)
+    return ;
+
+  if (done >= total)
+    progressBar->hide();
+  else if (!progressBar->isVisible())
+    progressBar->show();
+
+  progressBar->setRange(0, total);
+  progressBar->setValue(done);
+}
+
+void
+MainWindow::updatePlugin(void)
+{
+  if (!plugin)
+    return ;
+
+  plugin->fetchAll();
+
+#if QT_VERSION >= 0x040700
+  QNetworkConfigurationManager mgr;
+  QList<QNetworkConfiguration> configs;
+
+  configs = mgr.allConfigurations(QNetworkConfiguration::Active);
+
+  foreach (QNetworkConfiguration config, configs) {
+    QNetworkConfiguration::BearerType type = config.bearerType();
+
+    /* Don't fetch stations from network on slow links */
+    if (type != QNetworkConfiguration::BearerEthernet &&
+	type != QNetworkConfiguration::BearerWLAN &&
+	type != QNetworkConfiguration::BearerWiMAX)
+      return ;
+    else
+      break ;
+  }
+#endif
+
+  plugin->fetchOnline();
+}
