@@ -32,6 +32,7 @@
 class StationsPluginManager;
 class StationsPlugin;
 class Station;
+class QProgressBar;
 
 class MainWindow : public QMainWindow, private Ui_MainWindow
 {
@@ -47,6 +48,8 @@ class MainWindow : public QMainWindow, private Ui_MainWindow
 
  private slots:
   void delayedInit();
+  void updatePlugin();
+
   void about();
   void aboutQt();
 
@@ -57,6 +60,8 @@ class MainWindow : public QMainWindow, private Ui_MainWindow
   void buttonClicked();
   void setStationsPlugin(StationsPlugin *plugin, bool save = false);
 
+  void progress(qint64 done, qint64 total);
+
 #ifdef Q_WS_MAEMO_5
   void statusMsg(const QString & msg, int timeout = QMaemo5InformationBox::DefaultTimeout);
 #else
@@ -74,6 +79,7 @@ class MainWindow : public QMainWindow, private Ui_MainWindow
  private:
   StationsPluginManager *manager;
   StationsPlugin *plugin;
+  QProgressBar *progressBar;
 #ifdef HAVE_QT_LOCATION
   QGeoPositionInfoSource *localisation;
   QGeoPositionInfo position;
