@@ -25,6 +25,8 @@
 
 #include "config.h"
 
+#include "tools.h"
+#include "lugdulov.h"
 #include "settings.h"
 #include "stationsplugin.h"
 #include "station.h"
@@ -44,11 +46,7 @@ StationsListDialog::StationsListDialog(StationsPlugin *plugin, QWidget *parent)
   plugin(plugin)
 {
   setupUi(this);
-
-#ifdef Q_WS_MAEMO_5
-  setAttribute(Qt::WA_Maemo5StackedWindow);
-  setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-#endif
+  setupDialog(this);
 
   refreshButton->setIcon(QIcon::fromTheme("view-refresh", QPixmap(":/res/view-refresh.png")));
 #ifdef Q_WS_MAEMO_5
@@ -78,7 +76,6 @@ StationsListDialog::StationsListDialog(StationsPlugin *plugin, QWidget *parent)
 	  this, SLOT(error(const QString &, const QString &)));
 
   QTimer::singleShot(1, plugin, SLOT(fetchAll())); // First fetch cached data
-  QTimer::singleShot(200, plugin, SLOT(fetchOnline())); // Then load online data
 }
 
 StationsListDialog::~StationsListDialog()
