@@ -23,9 +23,9 @@
 #include "bruxelles_p.h"
 
 StationsPluginBruxelles::StationsPluginBruxelles(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateBruxelles();
+  d = new StationsPluginSimplePrivateBruxelles();
 }
 
 StationsPluginBruxelles::~StationsPluginBruxelles()
