@@ -21,9 +21,13 @@
 
 #include <QtCore/QString>
 
+class QNetworkRequest;
+
 class Tools {
  public:
   static QString ucFirst(const QString & str);
+  static void fixupRequest(QNetworkRequest * request);
+  static bool isOnline();
 };
 
 #endif
