@@ -23,9 +23,9 @@
 #include "creteil_p.h"
 
 StationsPluginCreteil::StationsPluginCreteil(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateCreteil();
+  d = new StationsPluginSimplePrivateCreteil();
 }
 
 StationsPluginCreteil::~StationsPluginCreteil()
@@ -42,7 +42,7 @@ StationsPluginCreteil::id() const
 QString
 StationsPluginCreteil::name() const
 {
-  return QString::fromUtf8("Creteil");
+  return QString::fromUtf8("Créteil");
 }
 
 QString
