@@ -23,9 +23,9 @@
 #include "marseille_p.h"
 
 StationsPluginMarseille::StationsPluginMarseille(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateMarseille();
+  d = new StationsPluginSimplePrivateMarseille();
 }
 
 StationsPluginMarseille::~StationsPluginMarseille()
