@@ -23,9 +23,9 @@
 #include "nancy_p.h"
 
 StationsPluginNancy::StationsPluginNancy(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateNancy();
+  d = new StationsPluginSimplePrivateNancy();
 }
 
 StationsPluginNancy::~StationsPluginNancy()
