@@ -23,9 +23,9 @@
 #include "santander_p.h"
 
 StationsPluginSantander::StationsPluginSantander(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateSantander();
+  d = new StationsPluginSimplePrivateSantander();
 }
 
 StationsPluginSantander::~StationsPluginSantander()
